# Foundation UI

## Overview

Foundation UI is a modern, accessible Vue 3 component library designed to provide a robust and flexible set of UI components for web applications.

## Features

- 🚀 Modern Vue 3 Components
- ♿ Accessibility First
- 🎨 Customizable Design System
- 📦 Easy Integration

## Installation

Install Foundation UI using npm:

```bash
npm install @yoosuf/foundation-ui
```

## Usage

### Import the Library

```typescript
import { createApp } from 'vue'
import App from './App.vue'
import FoundationUI from '@yoosuf/foundation-ui'
import '@yoosuf/foundation-ui/style.css'

const app = createApp(App)
app.use(FoundationUI)
```

## Development

### Prerequisites

- Node.js (v16+)
- npm

### Setup

1. Clone the repository
2. Install dependencies: `npm install`
3. Run development server: `npm run dev`
4. Build the library: `npm run build`

## Contributing

Contributions are welcome! Please see our [Contributing Guidelines](CONTRIBUTING.md) for more details.

## License

This project is licensed under the MIT License.

## Contact

- GitHub: [Foundation UI Repository](https://github.com/yoosuf/foundation-ui)
- Issues: [GitHub Issues](https://github.com/yoosuf/foundation-ui/issues)

## Changelog

See [CHANGELOG.md](CHANGELOG.md) for version history and changes.

## Components

### Button

#### Props
- `variant`: 'primary' | 'secondary' | 'tertiary'
- `size`: 'small' | 'medium' | 'large'
- `disabled`: boolean
- `type`: 'button' | 'submit' | 'reset'
- `fullWidth`: boolean

#### Events
- `click`: Emitted on button click

### Input

#### Props
- `modelValue`: string | number
- `type`: 'text' | 'password' | 'email' | 'number' | 'tel'
- `placeholder`: string
- `disabled`: boolean
- `required`: boolean
- `minLength`: number
- `maxLength`: number
- `pattern`: string
- `variant`: 'default' | 'outlined' | 'filled'
- `size`: 'small' | 'medium' | 'large'

#### Events
- `update:modelValue`: Emitted on input change
- `input`: Native input event
- `focus`: Emitted on input focus
- `blur`: Emitted on input blur

## 🎨 Customization

Customize components using CSS variables or theme configuration.

## 🤝 Contributing

1. Fork the repository
2. Create your feature branch (`git checkout -b feature/AmazingFeature`)
3. Commit your changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

## 📄 License

MIT License
